# Quick Start

In this section, we will walk through a few short examples that you can 
work through yourself to get a feel for how to use the yooink package. 

- [Setting up API access](api_setup.md)
- [Data overview](data_overview.md)
